@@ -15,6 +15,7 @@ from openshift.dynamic import DynamicClient
 from openshift.dynamic.exceptions import ConflictError, NotFoundError
 from openshift.dynamic.resource import ResourceField
 from packaging.version import Version
+from simple_logger.logger import get_logger
 
 from ocp_resources.constants import (
     DEFAULT_CLUSTER_RETRY_EXCEPTIONS,
@@ -24,7 +25,6 @@ from ocp_resources.constants import (
     TIMEOUT_4MINUTES,
 )
 from ocp_resources.event import Event
-from ocp_resources.logger import get_logger
 from ocp_resources.utils import (
     TimeoutExpiredError,
     TimeoutSampler,
@@ -125,7 +125,10 @@ class KubeAPIVersion(Version):
             with contextlib.suppress(ValueError):
                 components[idx] = int(obj)
 
-        errmsg = f"version '{vstring}' does not conform to kubernetes api versioning guidelines"
+        errmsg = (
+            f"version '{vstring}' does not conform to kubernetes api versioning"
+            " guidelines"
+        )
 
         if (
             len(components) not in (2, 4)
@@ -241,7 +244,9 @@ class Resource:
         CLONE_KUBEVIRT_IO = "clone.kubevirt.io"
         CONFIG_OPENSHIFT_IO = "config.openshift.io"
         CONSOLE_OPENSHIFT_IO = "console.openshift.io"
+        COORDINATION_K8S_IO = "coordination.k8s.io"
         DATA_IMPORT_CRON_TEMPLATE_KUBEVIRT_IO = "dataimportcrontemplate.kubevirt.io"
+        DISCOVERY_K8S_IO = "discovery.k8s.io"
         EVENTS_K8S_IO = "events.k8s.io"
         EXPORT_KUBEVIRT_IO = "export.kubevirt.io"
         FORKLIFT_KONVEYOR_IO = "forklift.konveyor.io"
@@ -250,6 +255,7 @@ class Resource:
         HOSTPATHPROVISIONER_KUBEVIRT_IO = "hostpathprovisioner.kubevirt.io"
         IMAGE_OPENSHIFT_IO = "image.openshift.io"
         IMAGE_REGISTRY = "registry.redhat.io"
+        INTEGREATLY_ORG = "integreatly.org"
         K8S_CNI_CNCF_IO = "k8s.cni.cncf.io"
         K8S_V1_CNI_CNCF_IO = "k8s.v1.cni.cncf.io"
         KUBERNETES_IO = "kubernetes.io"
@@ -260,6 +266,7 @@ class Resource:
         MACHINECONFIGURATION_OPENSHIFT_IO = "machineconfiguration.openshift.io"
         MAISTRA_IO = "maistra.io"
         METALLB_IO = "metallb.io"
+        METRICS_K8S_IO = "metrics.k8s.io"
         MIGRATIONS_KUBEVIRT_IO = "migrations.kubevirt.io"
         MONITORING_COREOS_COM = "monitoring.coreos.com"
         NETWORKADDONSOPERATOR_NETWORK_KUBEVIRT_IO = (
@@ -293,6 +300,7 @@ class Resource:
         STORAGECLASS_KUBERNETES_IO = "storageclass.kubernetes.io"
         SUBRESOURCES_KUBEVIRT_IO = "subresources.kubevirt.io"
         TEKTONTASKS_KUBEVIRT_IO = "tektontasks.kubevirt.io"
+        TEKTON_DEV = "tekton.dev"
         TEMPLATE_KUBEVIRT_IO = "template.kubevirt.io"
         TEMPLATE_OPENSHIFT_IO = "template.openshift.io"
         UPLOAD_CDI_KUBEVIRT_IO = "upload.cdi.kubevirt.io"
@@ -349,7 +357,8 @@ class Resource:
         self.api_group = api_group or self.api_group
         if not self.api_group and not self.api_version:
             raise NotImplementedError(
-                "Subclasses of Resource require self.api_group or self.api_version to be defined"
+                "Subclasses of Resource require self.api_group or self.api_version to"
+                " be defined"
             )
         self.namespace = None
         self.name = name
@@ -373,12 +382,21 @@ class Resource:
         self.res = None
         self.yaml_file_contents = None
         self.initial_resource_version = None
-        self.logger = get_logger(name=f"{__name__.rsplit('.')[0]} {self.kind}")
+        self.logger = self._set_logger()
         self.timeout_seconds = timeout_seconds
         self.hash_log_data = hash_log_data
         # self._set_client_and_api_version() must be last init line
         self._set_client_and_api_version()
 
+    def _set_logger(self):
+        log_level = os.environ.get("OPENSHIFT_PYTHON_WRAPPER_LOG_LEVEL", "INFO")
+        log_file = os.environ.get("OPENSHIFT_PYTHON_WRAPPER_LOG_FILE", "")
+        return get_logger(
+            name=f"{__name__.rsplit('.')[0]} {self.kind}",
+            level=log_level,
+            filename=log_file,
+        )
+
     def _prepare_node_selector_spec(self):
         if self.node_selector:
             return {f"{self.ApiGroup.KUBERNETES_IO}/hostname": self.node_selector}
@@ -497,7 +515,8 @@ class Resource:
             check_exists=False,
         ):
             self.logger.warning(
-                f"Skip resource {self.kind} {self.name} teardown. Got {_export_str}={skip_resource_teardown}"
+                f"Skip resource {self.kind} {self.name} teardown. Got"
+                f" {_export_str}={skip_resource_teardown}"
             )
             return
 
@@ -788,6 +807,7 @@ class Resource:
         config_file=None,
         context=None,
         singular_name=None,
+        exceptions_dict=DEFAULT_CLUSTER_RETRY_EXCEPTIONS,
         *args,
         **kwargs,
     ):
@@ -799,6 +819,7 @@ class Resource:
             config_file (str): Path to config file for connecting to remote cluster.
             context (str): Context name for connecting to remote cluster.
             singular_name (str): Resource kind (in lowercase), in use where we have multiple matches for resource.
+            exceptions_dict (dict): Exceptions dict for TimeoutSampler
 
         Returns:
             generator: Generator of Resources of cls.kind
@@ -816,7 +837,9 @@ class Resource:
             except TypeError:
                 yield cls(client=dyn_client, name=_resources.metadata.name)
 
-        return Resource.retry_cluster_exceptions(func=_get)
+        return Resource.retry_cluster_exceptions(
+            func=_get, exceptions_dict=exceptions_dict
+        )
 
     @property
     def instance(self):
@@ -877,14 +900,18 @@ class Resource:
             TimeoutExpiredError: If Resource condition in not in desire status.
         """
         self.logger.info(
-            f"Wait for {self.kind}/{self.name}'s '{condition}' condition to be '{status}'"
+            f"Wait for {self.kind}/{self.name}'s '{condition}' condition to be"
+            f" '{status}'"
         )
         for sample in self.watcher(timeout=timeout):
             for cond in sample["raw_object"].get("status", {}).get("conditions", []):
                 if cond["type"] == condition and cond["status"] == status:
                     return
         raise TimeoutExpiredError(
-            value=f"condition {condition} not in desired status {status} after {timeout} seconds"
+            value=(
+                f"condition {condition} not in desired status {status} after"
+                f" {timeout} seconds"
+            )
         )
 
     def api_request(self, method, action, url, **params):
@@ -1230,7 +1257,7 @@ class ResourceEditor:
                         self._backups[resource] = backup
                     else:
                         LOGGER.warning(
-                            f"ResourceEdit: no diff found in patch for "
+                            "ResourceEdit: no diff found in patch for "
                             f"{resource.name} -- skipping"
                         )
                 if not resource_to_patch:
