@@ -1,4 +1,3 @@
-import datetime
 import time
 
 import yaml
@@ -124,8 +123,7 @@ class TimeoutSampler:
         timeout_watch = TimeoutWatch(timeout=self.wait_timeout)
         if self.print_log:
             LOGGER.info(
-                f"Waiting for {self.wait_timeout} seconds"
-                f" [{datetime.timedelta(seconds=self.wait_timeout)}], retry every"
+                f"Waiting for {self.wait_timeout} seconds, retry every"
                 f" {self.sleep} seconds. ({self._func_log})"
             )
 
@@ -138,20 +136,19 @@ class TimeoutSampler:
 
                 time.sleep(self.sleep)
 
-            except Exception as exp:
+            except self._exceptions as exp:
                 last_exp = exp
+                last_exp_log = self._get_exception_log(exp=last_exp)
                 if self._is_raisable_exception(exp=last_exp):
-                    raise TimeoutExpiredError(self._get_exception_log(exp=last_exp))
+                    LOGGER.error(last_exp_log)
+                    raise exp
 
                 self.elapsed_time = None
                 time.sleep(self.sleep)
 
             finally:
                 if self.elapsed_time and self.print_log:
-                    LOGGER.info(
-                        "Elapsed time:"
-                        f" {self.elapsed_time} [{datetime.timedelta(seconds=self.elapsed_time)}]"
-                    )
+                    LOGGER.info(f"Elapsed time: {self.elapsed_time}")
 
         raise TimeoutExpiredError(self._get_exception_log(exp=last_exp))
 
